from datetime import datetime

from database.models import *
from tests import TestingSessionLocal
from pytest import fixture


@fixture
def get_test_db():
    try:
        db = TestingSessionLocal()
        yield db
    finally:
        db.close()


def test_users(get_test_db):
    test = get_test_db.query(Users).filter(Users.id == 260).first()
    assert test.email == "testaccountjugador@gmail.com"


def test_cities(get_test_db):
    test = get_test_db.query(Cities).filter(Cities.id == 7).first()
    assert test.name == "Lyon"


def test_games(get_test_db):
    test = get_test_db.query(Games).filter(Games.id == 508).first()
    assert test.user_id == 1978


def test_payments(get_test_db):
    test = get_test_db.query(Payments).filter(Payments.id == 375).first()
    assert test.user_id == 88


def test_player_availabilities(get_test_db):
    test = (
        get_test_db.query(PlayerAvailabilities)
        .filter(PlayerAvailabilities.id == 248)
        .first()
    )
    assert test.game_id == 89


def test_player_cancel_games(get_test_db):
    test = (
        get_test_db.query(PlayerCancelGames).filter(PlayerCancelGames.id == 67).first()
    )
    assert test.player_id == 44


def test_purchase_games(get_test_db):
    test = get_test_db.query(PurchaseGames).filter(PurchaseGames.id == 235).first()
    assert test.game_id == 50


def test_sports(get_test_db):
    test = get_test_db.query(Sports).filter(Sports.id == 4).first()
    assert test.name == "Volleyball"


def test_teams(get_test_db):
    test = get_test_db.query(Teams).filter(Teams.id == 306).first()
    assert test.game_id == 64


def test_user_ratings(get_test_db):
    test = get_test_db.query(UserRatings).filter(UserRatings.id == 287).first()
    assert test.user_id == 60


def test_venue_images(get_test_db):
    test = get_test_db.query(VenueImages).filter(VenueImages.id == 3).first()
    date = datetime(year=2019, month=6, day=3, hour=5, minute=43, second=22)
    assert test.created == date


def test_venues(get_test_db):
    test = get_test_db.query(Venues).filter(Venues.id == 26).first()
    assert test.name == "Le tuto "


def test_web_bookings(get_test_db):
    test = get_test_db.query(WebBookings).filter(WebBookings.id == 7).first()
    assert test.game == "Soccer"
